//
// Copyright 2023 Pixar
//
// Licensed under the Apache License, Version 2.0 (the "Apache License")
// with the following modification; you may not use this file except in
// compliance with the Apache License and the following modification to it:
// Section 6. Trademarks. is deleted and replaced with:
//
// 6. Trademarks. This License does not grant permission to use the trade
//    names, trademarks, service marks, or product names of the Licensor
//    and its affiliates, except as required to comply with Section 4(c) of
//    the License and to reproduce the content of the NOTICE file.
//
// You may obtain a copy of the Apache License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the Apache License with the above modification is
// distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied. See the Apache License for the specific
// language governing permissions and limitations under the Apache License.
//
////////////////////////////////////////////////////////////////////////

/* ************************************************************************** */
/* ** This file is generated by a script.  Do not edit directly.  Edit     ** */
/* ** defs.py or the (*)Schema.template.cpp files to make changes.         ** */
/* ************************************************************************** */

#include "pxr/imaging/hd/modelSchema.h"
#include "pxr/imaging/hd/retainedDataSource.h"

#include "pxr/base/trace/trace.h"


PXR_NAMESPACE_OPEN_SCOPE

TF_DEFINE_PUBLIC_TOKENS(HdModelSchemaTokens,
    HDMODEL_SCHEMA_TOKENS);



HdTokenDataSourceHandle
HdModelSchema::GetDrawMode()
{
    return _GetTypedDataSource<HdTokenDataSource>(
        HdModelSchemaTokens->drawMode);
}

HdBoolDataSourceHandle
HdModelSchema::GetApplyDrawMode()
{
    return _GetTypedDataSource<HdBoolDataSource>(
        HdModelSchemaTokens->applyDrawMode);
}

HdVec3fDataSourceHandle
HdModelSchema::GetDrawModeColor()
{
    return _GetTypedDataSource<HdVec3fDataSource>(
        HdModelSchemaTokens->drawModeColor);
}

HdTokenDataSourceHandle
HdModelSchema::GetCardGeometry()
{
    return _GetTypedDataSource<HdTokenDataSource>(
        HdModelSchemaTokens->cardGeometry);
}

HdAssetPathDataSourceHandle
HdModelSchema::GetCardTextureXPos()
{
    return _GetTypedDataSource<HdAssetPathDataSource>(
        HdModelSchemaTokens->cardTextureXPos);
}

HdAssetPathDataSourceHandle
HdModelSchema::GetCardTextureYPos()
{
    return _GetTypedDataSource<HdAssetPathDataSource>(
        HdModelSchemaTokens->cardTextureYPos);
}

HdAssetPathDataSourceHandle
HdModelSchema::GetCardTextureZPos()
{
    return _GetTypedDataSource<HdAssetPathDataSource>(
        HdModelSchemaTokens->cardTextureZPos);
}

HdAssetPathDataSourceHandle
HdModelSchema::GetCardTextureXNeg()
{
    return _GetTypedDataSource<HdAssetPathDataSource>(
        HdModelSchemaTokens->cardTextureXNeg);
}

HdAssetPathDataSourceHandle
HdModelSchema::GetCardTextureYNeg()
{
    return _GetTypedDataSource<HdAssetPathDataSource>(
        HdModelSchemaTokens->cardTextureYNeg);
}

HdAssetPathDataSourceHandle
HdModelSchema::GetCardTextureZNeg()
{
    return _GetTypedDataSource<HdAssetPathDataSource>(
        HdModelSchemaTokens->cardTextureZNeg);
}

/*static*/
HdContainerDataSourceHandle
HdModelSchema::BuildRetained(
        const HdTokenDataSourceHandle &drawMode,
        const HdBoolDataSourceHandle &applyDrawMode,
        const HdVec3fDataSourceHandle &drawModeColor,
        const HdTokenDataSourceHandle &cardGeometry,
        const HdAssetPathDataSourceHandle &cardTextureXPos,
        const HdAssetPathDataSourceHandle &cardTextureYPos,
        const HdAssetPathDataSourceHandle &cardTextureZPos,
        const HdAssetPathDataSourceHandle &cardTextureXNeg,
        const HdAssetPathDataSourceHandle &cardTextureYNeg,
        const HdAssetPathDataSourceHandle &cardTextureZNeg
)
{
    TfToken names[10];
    HdDataSourceBaseHandle values[10];

    size_t count = 0;
    if (drawMode) {
        names[count] = HdModelSchemaTokens->drawMode;
        values[count++] = drawMode;
    }

    if (applyDrawMode) {
        names[count] = HdModelSchemaTokens->applyDrawMode;
        values[count++] = applyDrawMode;
    }

    if (drawModeColor) {
        names[count] = HdModelSchemaTokens->drawModeColor;
        values[count++] = drawModeColor;
    }

    if (cardGeometry) {
        names[count] = HdModelSchemaTokens->cardGeometry;
        values[count++] = cardGeometry;
    }

    if (cardTextureXPos) {
        names[count] = HdModelSchemaTokens->cardTextureXPos;
        values[count++] = cardTextureXPos;
    }

    if (cardTextureYPos) {
        names[count] = HdModelSchemaTokens->cardTextureYPos;
        values[count++] = cardTextureYPos;
    }

    if (cardTextureZPos) {
        names[count] = HdModelSchemaTokens->cardTextureZPos;
        values[count++] = cardTextureZPos;
    }

    if (cardTextureXNeg) {
        names[count] = HdModelSchemaTokens->cardTextureXNeg;
        values[count++] = cardTextureXNeg;
    }

    if (cardTextureYNeg) {
        names[count] = HdModelSchemaTokens->cardTextureYNeg;
        values[count++] = cardTextureYNeg;
    }

    if (cardTextureZNeg) {
        names[count] = HdModelSchemaTokens->cardTextureZNeg;
        values[count++] = cardTextureZNeg;
    }

    return HdRetainedContainerDataSource::New(count, names, values);
}

/*static*/
HdModelSchema
HdModelSchema::GetFromParent(
        const HdContainerDataSourceHandle &fromParentContainer)
{
    return HdModelSchema(
        fromParentContainer
        ? HdContainerDataSource::Cast(fromParentContainer->Get(
                HdModelSchemaTokens->model))
        : nullptr);
}

/*static*/
const TfToken &
HdModelSchema::GetSchemaToken()
{
    return HdModelSchemaTokens->model;
}

/*static*/
const HdDataSourceLocator &
HdModelSchema::GetDefaultLocator()
{
    static const HdDataSourceLocator locator(
        HdModelSchemaTokens->model
    );
    return locator;
} 
/*static*/
const HdDataSourceLocator &
HdModelSchema::GetDrawModeLocator()
{
    static const HdDataSourceLocator locator(
        HdModelSchemaTokens->model,
        HdModelSchemaTokens->drawMode
    );
    return locator;
}


HdModelSchema::Builder &
HdModelSchema::Builder::SetDrawMode(
    const HdTokenDataSourceHandle &drawMode)
{
    _drawMode = drawMode;
    return *this;
}

HdModelSchema::Builder &
HdModelSchema::Builder::SetApplyDrawMode(
    const HdBoolDataSourceHandle &applyDrawMode)
{
    _applyDrawMode = applyDrawMode;
    return *this;
}

HdModelSchema::Builder &
HdModelSchema::Builder::SetDrawModeColor(
    const HdVec3fDataSourceHandle &drawModeColor)
{
    _drawModeColor = drawModeColor;
    return *this;
}

HdModelSchema::Builder &
HdModelSchema::Builder::SetCardGeometry(
    const HdTokenDataSourceHandle &cardGeometry)
{
    _cardGeometry = cardGeometry;
    return *this;
}

HdModelSchema::Builder &
HdModelSchema::Builder::SetCardTextureXPos(
    const HdAssetPathDataSourceHandle &cardTextureXPos)
{
    _cardTextureXPos = cardTextureXPos;
    return *this;
}

HdModelSchema::Builder &
HdModelSchema::Builder::SetCardTextureYPos(
    const HdAssetPathDataSourceHandle &cardTextureYPos)
{
    _cardTextureYPos = cardTextureYPos;
    return *this;
}

HdModelSchema::Builder &
HdModelSchema::Builder::SetCardTextureZPos(
    const HdAssetPathDataSourceHandle &cardTextureZPos)
{
    _cardTextureZPos = cardTextureZPos;
    return *this;
}

HdModelSchema::Builder &
HdModelSchema::Builder::SetCardTextureXNeg(
    const HdAssetPathDataSourceHandle &cardTextureXNeg)
{
    _cardTextureXNeg = cardTextureXNeg;
    return *this;
}

HdModelSchema::Builder &
HdModelSchema::Builder::SetCardTextureYNeg(
    const HdAssetPathDataSourceHandle &cardTextureYNeg)
{
    _cardTextureYNeg = cardTextureYNeg;
    return *this;
}

HdModelSchema::Builder &
HdModelSchema::Builder::SetCardTextureZNeg(
    const HdAssetPathDataSourceHandle &cardTextureZNeg)
{
    _cardTextureZNeg = cardTextureZNeg;
    return *this;
}

HdContainerDataSourceHandle
HdModelSchema::Builder::Build()
{
    return HdModelSchema::BuildRetained(
        _drawMode,
        _applyDrawMode,
        _drawModeColor,
        _cardGeometry,
        _cardTextureXPos,
        _cardTextureYPos,
        _cardTextureZPos,
        _cardTextureXNeg,
        _cardTextureYNeg,
        _cardTextureZNeg
    );
}


PXR_NAMESPACE_CLOSE_SCOPE